require 'bcaparser/time_keeper'

module BcaParser
  describe "TimeKeeper" do

    it "successfuly check if a year is a leap year" do
      year = 2000
      expect(TimeKeeper.checkLeapYear(year)).to eq(true)
    end

    it "is invalid leap year if it is divisible by 4 and 100 but not 400" do
      year = 2100
      expect(TimeKeeper.checkLeapYear(year)).to eq(false)
    end

    it "is valid leap year if it is divisible by 4, but not divisible by 100 and 400" do
      year = 2004
      expect(TimeKeeper.checkLeapYear(year)).to eq(true)
    end

    it "is a invalid month" do
      month = 18
      day = 1
      expect(TimeKeeper.checkDayMonth(day, month)).to eq(false)
    end

    it "is a valid month" do
      month = 12
      day = 1
      expect(TimeKeeper.checkDayMonth(day, month)).to eq(true)
    end

    it "is a valid date" do
      month = 5
      day = 31
      expect(TimeKeeper.checkDayMonth(day, month)).to eq(true)
    end

    it "is an invalid date" do
      month = 2
      day = 29
      year = 2014

      expect(TimeKeeper.checkDayMonth(day, month, year)).to eq(false)
    end

    it "valid if end date is bigger than start date" do
      start_day = Time.new(2014, 1, 1)
      end_day = Time.new(2014, 1, 25)
      expect(TimeKeeper.compareDate(start_day, end_day)).to eq(true)
    end

    it "is valid if it is in the range of 31 days between start and end date" do
      start_day = "1"
      start_month = "1"
      end_day = "25"
      end_month = "1"
      expect(TimeKeeper.checkDateForBalance(start_day, start_month, end_day, end_month)).to eq(true)
    end

    it "is invalid if it is outside the range of 31 days between start and end date" do
      start_day = "1"
      start_month = "2"
      end_day = "25"
      end_month = "5"
      expect(TimeKeeper.checkDateForBalance(start_day, start_month, end_day, end_month)).to eq(false)
    end
  end

end